ExecutionEngineConfigBuilder

Struct ExecutionEngineConfigBuilder 

pub struct ExecutionEngineConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ExecutionEngineConfigBuilder<S>

pub fn build(self) -> ExecutionEngineConfig
where S: IsComplete,

Finish building and return the requested object

pub fn load_cache( self, value: bool, ) -> ExecutionEngineConfigBuilder<SetLoadCache<S>>
where S::LoadCache: IsUnset,

Optional (Some / Option setters). Default: true.

If the cache should be loaded on initialization.

pub fn maybe_load_cache( self, value: Option<bool>, ) -> ExecutionEngineConfigBuilder<SetLoadCache<S>>
where S::LoadCache: IsUnset,

Optional (Some / Option setters). Default: true.

If the cache should be loaded on initialization.

pub fn manage_own_order_books( self, value: bool, ) -> ExecutionEngineConfigBuilder<SetManageOwnOrderBooks<S>>
where S::ManageOwnOrderBooks: IsUnset,

Optional (Some / Option setters). Default: false.

If the execution engine should maintain own/user order books based on commands and events.

pub fn maybe_manage_own_order_books( self, value: Option<bool>, ) -> ExecutionEngineConfigBuilder<SetManageOwnOrderBooks<S>>
where S::ManageOwnOrderBooks: IsUnset,

Optional (Some / Option setters). Default: false.

If the execution engine should maintain own/user order books based on commands and events.

pub fn snapshot_orders( self, value: bool, ) -> ExecutionEngineConfigBuilder<SetSnapshotOrders<S>>
where S::SnapshotOrders: IsUnset,

Optional (Some / Option setters). Default: false.

If order state snapshot lists are persisted to a backing database. Snapshots will be taken at every order state update (when events are applied).

pub fn maybe_snapshot_orders( self, value: Option<bool>, ) -> ExecutionEngineConfigBuilder<SetSnapshotOrders<S>>
where S::SnapshotOrders: IsUnset,

Optional (Some / Option setters). Default: false.

If order state snapshot lists are persisted to a backing database. Snapshots will be taken at every order state update (when events are applied).

pub fn snapshot_positions( self, value: bool, ) -> ExecutionEngineConfigBuilder<SetSnapshotPositions<S>>
where S::SnapshotPositions: IsUnset,

Optional (Some / Option setters). Default: false.

If position state snapshot lists are persisted to a backing database. Snapshots will be taken at position opened, changed and closed (when events are applied).

pub fn maybe_snapshot_positions( self, value: Option<bool>, ) -> ExecutionEngineConfigBuilder<SetSnapshotPositions<S>>
where S::SnapshotPositions: IsUnset,

Optional (Some / Option setters). Default: false.

If position state snapshot lists are persisted to a backing database. Snapshots will be taken at position opened, changed and closed (when events are applied).

pub fn snapshot_positions_interval_secs( self, value: f64, ) -> ExecutionEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>
where S::SnapshotPositionsIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) at which additional position state snapshots are persisted. If None then no additional snapshots will be taken.

pub fn maybe_snapshot_positions_interval_secs( self, value: Option<f64>, ) -> ExecutionEngineConfigBuilder<SetSnapshotPositionsIntervalSecs<S>>
where S::SnapshotPositionsIntervalSecs: IsUnset,

Optional (Some / Option setters). The interval (seconds) at which additional position state snapshots are persisted. If None then no additional snapshots will be taken.

pub fn allow_overfills( self, value: bool, ) -> ExecutionEngineConfigBuilder<SetAllowOverfills<S>>
where S::AllowOverfills: IsUnset,

Optional (Some / Option setters). Default: false.

If order fills exceeding order quantity are allowed (logs warning instead of raising). Useful when position reconciliation races with exchange fill events.

pub fn maybe_allow_overfills( self, value: Option<bool>, ) -> ExecutionEngineConfigBuilder<SetAllowOverfills<S>>
where S::AllowOverfills: IsUnset,

Optional (Some / Option setters). Default: false.

If order fills exceeding order quantity are allowed (logs warning instead of raising). Useful when position reconciliation races with exchange fill events.

pub fn external_clients( self, value: Vec<ClientId>, ) -> ExecutionEngineConfigBuilder<SetExternalClients<S>>
where S::ExternalClients: IsUnset,

Optional (Some / Option setters). The client IDs declared for external stream processing.

The execution engine will not attempt to send trading commands to these client IDs, assuming an external process will consume the serialized command messages from the bus and handle execution.

pub fn maybe_external_clients( self, value: Option<Vec<ClientId>>, ) -> ExecutionEngineConfigBuilder<SetExternalClients<S>>
where S::ExternalClients: IsUnset,

Optional (Some / Option setters). The client IDs declared for external stream processing.

The execution engine will not attempt to send trading commands to these client IDs, assuming an external process will consume the serialized command messages from the bus and handle execution.

pub fn purge_closed_orders_interval_mins( self, value: u32, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>
where S::PurgeClosedOrdersIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed orders from the in-memory cache.

pub fn maybe_purge_closed_orders_interval_mins( self, value: Option<u32>, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedOrdersIntervalMins<S>>
where S::PurgeClosedOrdersIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed orders from the in-memory cache.

pub fn purge_closed_orders_buffer_mins( self, value: u32, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>
where S::PurgeClosedOrdersBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed orders can be purged.

pub fn maybe_purge_closed_orders_buffer_mins( self, value: Option<u32>, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedOrdersBufferMins<S>>
where S::PurgeClosedOrdersBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed orders can be purged.

pub fn purge_closed_positions_interval_mins( self, value: u32, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>
where S::PurgeClosedPositionsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed positions from the in-memory cache.

pub fn maybe_purge_closed_positions_interval_mins( self, value: Option<u32>, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedPositionsIntervalMins<S>>
where S::PurgeClosedPositionsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging closed positions from the in-memory cache.

pub fn purge_closed_positions_buffer_mins( self, value: u32, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>
where S::PurgeClosedPositionsBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed positions can be purged.

pub fn maybe_purge_closed_positions_buffer_mins( self, value: Option<u32>, ) -> ExecutionEngineConfigBuilder<SetPurgeClosedPositionsBufferMins<S>>
where S::PurgeClosedPositionsBufferMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before closed positions can be purged.

pub fn purge_account_events_interval_mins( self, value: u32, ) -> ExecutionEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>
where S::PurgeAccountEventsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging account events from the in-memory cache.

pub fn maybe_purge_account_events_interval_mins( self, value: Option<u32>, ) -> ExecutionEngineConfigBuilder<SetPurgeAccountEventsIntervalMins<S>>
where S::PurgeAccountEventsIntervalMins: IsUnset,

Optional (Some / Option setters). The interval (minutes) between purging account events from the in-memory cache.

pub fn purge_account_events_lookback_mins( self, value: u32, ) -> ExecutionEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>
where S::PurgeAccountEventsLookbackMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before account events can be purged.

pub fn maybe_purge_account_events_lookback_mins( self, value: Option<u32>, ) -> ExecutionEngineConfigBuilder<SetPurgeAccountEventsLookbackMins<S>>
where S::PurgeAccountEventsLookbackMins: IsUnset,

Optional (Some / Option setters). The time buffer (minutes) before account events can be purged.

pub fn purge_from_database( self, value: bool, ) -> ExecutionEngineConfigBuilder<SetPurgeFromDatabase<S>>
where S::PurgeFromDatabase: IsUnset,

Optional (Some / Option setters). Default: false.

If purge operations should also delete from the backing database.

pub fn maybe_purge_from_database( self, value: Option<bool>, ) -> ExecutionEngineConfigBuilder<SetPurgeFromDatabase<S>>
where S::PurgeFromDatabase: IsUnset,

Optional (Some / Option setters). Default: false.

If purge operations should also delete from the backing database.

pub fn debug(self, value: bool) -> ExecutionEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).

pub fn maybe_debug( self, value: Option<bool>, ) -> ExecutionEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).